@@ -38,14 +38,7 @@ class Signal(BridgeH5):
 
     def __getitem__(self, dsets):
 
-        # if isinstance(dsets, str) and dsets.endswith("imBackground"):
-        # df = self.get_raw(dsets)
-        if (
-            isinstance(dsets, str)
-            and dsets.endswith("imBackground")
-            # or dsets.startswith("postprocessing")
-            # or dsets.startswith("/postprocessing")
-        ):
+        if isinstance(dsets, str) and dsets.endswith("imBackground"):
             df = self.get_raw(dsets)
 
         elif isinstance(dsets, str):
@@ -72,44 +65,30 @@ class Signal(BridgeH5):
             merged = df
             if merges.any():
                 # Split in two dfs, one with rows relevant for merging and one without them
-                mergeable_ids = merges.reshape(-1, 2)
-                valid_ids = mergeable_ids[  # Casting allows fast multiindexing
-                    (
-                        mergeable_ids.T[:, :, None]
-                        == np.array(list(df.index)).T[:, None, :]
-                    )
-                    .all(axis=0)
+                valid_merges = merges[
+                    (merges[:, :, :, None] == np.array(list(df.index)).T[:, None, :])
+                    .all(axis=(1, 2))
                     .any(axis=1)
-                ]
-                # df.index.intersection(
-                #     pd.MultiIndex.from_arrays(
-                #         np.unique(merges.reshape(-1, 2), axis=0).T,
-                #         names=df.index.names,
-                #     )
-                # )
+                ]  # Casting allows fast multiindexing
 
-                merged = self.apply_merge(df.loc[df.loc[map(tuple, valid_ids)]], merges)
+                merged = self.apply_merge(
+                    df.loc[map(tuple, valid_merges.reshape(-1, 2))], valid_merges
+                )
 
-                nonmergeable_ids = df.index.difference(mergeable_ids)
+                nonmergeable_ids = df.index.difference(valid_merges.reshape(-1, 2))
 
                 merged = pd.concat(
                     (merged, df.loc[nonmergeable_ids]), names=df.index.names
                 )
 
-            search = lambda a, b: np.where(
-                np.in1d(
-                    np.ravel_multi_index(a.T, a.max(0) + 1),
-                    np.ravel_multi_index(b.T, a.max(0) + 1),
-                )
-            )
             if "modifiers/picks" in f:
                 picks = self.get_picks(names=merged.index.names)
                 # missing_cells = [i for i in picks if tuple(i) not in set(merged.index)]
 
                 if picks:
-                    # return merged.loc[
-                    #     set(picks).intersection([tuple(x) for x in merged.index])
-                    # ]
+                    return merged.loc[
+                        set(picks).intersection([tuple(x) for x in merged.index])
+                    ]
                     return merged.loc[picks]
                 else:
                     if isinstance(merged.index, pd.MultiIndex):
@@ -167,11 +146,15 @@ class Signal(BridgeH5):
         return df
 
     def get_raw(self, dataset):
-        if isinstance(dataset, str):
-            with h5py.File(self.filename, "r") as f:
-                return self.dset_to_df(f, dataset)
-        elif isinstance(dataset, list):
-            return [self.get_raw(dset) for dset in dataset]
+        try:
+            if isinstance(dataset, str):
+                with h5py.File(self.filename, "r") as f:
+                    return self.dset_to_df(f, dataset)
+            elif isinstance(dataset, list):
+                return [self.get_raw(dset) for dset in dataset]
+        except Exception as e:
+            print(f"Could not fetch dataset {dataset}")
+            print(e)
 
     def get_merges(self):
         # fetch merge events going up to the first level
